# New in 0.15.1 (2022-03-11)

## Changes

-   Remove `labels_key` from {class}`~scvi.model.MULTIVI` as it is not used in the model ([#1393]).
-   Use scvi-tools mean/inv_disp parameterization of negative binomial for {class}`~scvi.model.JaxSCVI` likelihood ([#1386]).
-   Use `setup` for Flax-based modules ([#1403]).
-   Reimplement {class}`~scvi.module.JaxVAE` using inference/generative paradigm with {class}`~scvi.module.base.JaxBaseModuleClass` ([#1406]).
-   Use multiple particles optionally in {class}`~scvi.model.JaxSCVI` ([#1385]).
-   {class}`~scvi.external.SOLO` no longer warns about count data ([#1411]).
-   Class docs are now one page on docs site ([#1415]).
-   Copied AnnData objects are assigned a new uuid and transfer is attempted ([#1416]).

## Bug fixes

-   Fix an issue with using gene lists and proteins lists as well as `transform_batch` for {class}`~scvi.model.TOTALVI` ([#1413]).
-   Error gracefully when NaNs present in {class}`~scvi.data.fields.CategoricalJointObsmField` ([#1417]).

## Contributors

-   [@jjhong922]
-   [@adamgayoso]

[#1385]: https://github.com/YosefLab/scvi-tools/pull/1385
[#1386]: https://github.com/YosefLab/scvi-tools/pull/1386
[#1393]: https://github.com/YosefLab/scvi-tools/pull/1393
[#1403]: https://github.com/YosefLab/scvi-tools/pull/1403
[#1406]: https://github.com/YosefLab/scvi-tools/pull/1406
[#1411]: https://github.com/YosefLab/scvi-tools/pull/1411
[#1413]: https://github.com/YosefLab/scvi-tools/pull/1413
[#1415]: https://github.com/YosefLab/scvi-tools/pull/1415
[#1416]: https://github.com/YosefLab/scvi-tools/pull/1416
[#1417]: https://github.com/YosefLab/scvi-tools/pull/1417
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
